import { TaskResult } from "@fern-api/task-context";
const EMPTY_DEPENDENCIES_CONFIGURATION = {
    dependencies: {},
};
export async function convertDependenciesConfiguration({ rawDependenciesConfiguration, context, }) {
    if (rawDependenciesConfiguration == null) {
        return EMPTY_DEPENDENCIES_CONFIGURATION;
    }
    const dependencies = {};
    for (const [coordinate, version] of Object.entries(rawDependenciesConfiguration.dependencies)) {
        const unprefixedCoordinate = coordinate.substring(1);
        const splitCoordinate = unprefixedCoordinate.split("/");
        const organization = splitCoordinate[0];
        const apiName = splitCoordinate[1];
        if (organization != null && apiName != null) {
            dependencies[coordinate] = {
                organization,
                apiName,
                version,
            };
        }
        else {
            // don't throw so we can log all failures
            context.failWithoutThrowing(`Failed to parse dependency: ${coordinate}`);
        }
    }
    if (context.getResult() === TaskResult.Failure) {
        context.failAndThrow();
    }
    return {
        dependencies,
    };
}
